﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class PlayerController : MonoBehaviour 
{
	[Header ("MOVING")]
	public float speed = 0;

	[Header ("JUMPING")]
	public bool jumpEnable = false;
	public float jumpForce = 100;
	public Rigidbody2D rigidBody;

	[Header ("ATACKING")]
	public bool attackEnable = true;
	public int degrees = 45;
	public Weapon weapon;

	[Header ("HP")]
	public int health = 100;

	void Update ()
	{
		float axis = Input.GetAxis ("Horizontal");

		transform.Translate (Vector3.right * axis * speed);

		if (attackEnable && Input.GetKeyDown (KeyCode.K))
		{
			attackEnable = false;
			StartCoroutine (Attack ());
		}

		if (attackEnable && Input.GetKeyDown (KeyCode.L))
		{
			attackEnable = false;
			StartCoroutine (AttackFireball ());
		}
	}

	void FixedUpdate ()
	{
		if (jumpEnable && (Input.GetKeyDown (KeyCode.J) || Input.GetKeyDown (KeyCode.Space)))
		{
			Jump ();
		}
	}

	public IEnumerator Attack ()
	{
		weapon.pivot.Rotate (Vector3.back * degrees);

		yield return new WaitForSecondsRealtime (0.7f);

		weapon.pivot.Rotate (Vector3.forward * degrees);

		attackEnable = true;
	}

	public IEnumerator AttackFireball ()
	{
		weapon.pivot.Rotate (Vector3.back * degrees);

		weapon.LaunchFireball ();

		yield return new WaitForSecondsRealtime (0.7f);

		weapon.pivot.Rotate (Vector3.forward * degrees);

		attackEnable = true;
	}

	void Jump ()
	{
		jumpEnable = false;

		rigidBody.AddForce (Vector2.up * jumpForce * Time.deltaTime, ForceMode2D.Impulse);
	}

	void OnCollisionEnter2D (Collision2D other)
	{
		if (other.gameObject.tag == "Floor")
		{
			jumpEnable = true;
		}

		if (other.gameObject.tag == "Enemy")
		{
			health -= 10;
		}
	}
}